##  Accessing SaaS Discovery Inbox
You can access the SaaS discovery inbox from the inventory by going to Inventory Tools and selecting Discovery Inbox > SaaS Discovery from the dropdown. By default, only admins can access it, but admins can configure permissions to grant access to other roles. For more details, see [Role-Based Permissions](https://help.sap.com/docs/leanix/ea/user-roles-and-permissions?locale=en-US&state=PRODUCTION&version=CLOUD#loio275def827a4410149362f3672c614956__role-based_permissions).
![Accessing SaaS Discovery Inbox from the Inventory](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2755f6747a4410149981e55fa351768f_LowRes.png)
Accessing SaaS Discovery Inbox from the Inventory
